pub struct DeleteAccountV2 {
pub storage_config: Pubkey,
pub user_info: Pubkey,
pub storage_account: Pubkey,
pub stake_account: Pubkey,
pub owner: Pubkey,
pub shdw_payer: Pubkey,
pub uploader: Pubkey,
pub emissions_wallet: Pubkey,
pub token_mint: Pubkey,
pub system_program: Pubkey,
pub token_program: Pubkey,
}Expand description
Generated client accounts for DeleteAccountV2.
Fields
storage_config: PubkeyThis is the StorageConfig accounts that holds all of the admin, uploader keys.
user_info: PubkeyThis account is a PDA that holds a user’s info (not specific to one storage account).
storage_account: PubkeyParent storage account.
stake_account: PubkeyThis token account serves as the account which holds user’s stake for file storage.
owner: PubkeyFile owner, user Also, our uploader keys are signing this transaction so presuamably we would only provide a good key. We also may not need this account at all.
shdw_payer: PubkeyThis is the user’s token account, presumably with which they staked
uploader: PubkeyAdmin/uploader
emissions_wallet: PubkeyThis token accountis the SHDW operator emissions wallet
token_mint: PubkeyToken mint account
system_program: PubkeySystem Program
token_program: PubkeyToken Program