pub struct InitializeStorageAccountV1 {
pub storage_config: Pubkey,
pub user_info: Pubkey,
pub storage_account: Pubkey,
pub stake_account: Pubkey,
pub token_mint: Pubkey,
pub owner_1: Pubkey,
pub uploader: Pubkey,
pub owner_1_token_account: Pubkey,
pub system_program: Pubkey,
pub token_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for InitializeStorageAccountV1.
Fields
storage_config: PubkeyThis account is a PDA that holds the storage configuration, including current cost per byte,
user_info: PubkeyThis account is a PDA that holds a user’s info (not specific to one storage account).
storage_account: PubkeyThis account is a PDA that holds a user’s StorageAccount information.
stake_account: PubkeyThis token account serves as the account which holds user’s stake for file storage.
token_mint: PubkeyThis is the token in question for staking.
owner_1: PubkeyThis is the user who is initializing the storage account and is automatically added as an admin
uploader: PubkeyUploader needs to sign as this txn needs to be fulfilled on the middleman server to create the ceph bucket
owner_1_token_account: PubkeyThis is the user’s token account with which they are staking
system_program: PubkeySystem Program
token_program: PubkeyToken Program
rent: PubkeyRent Program