pub struct MakeAccountImmutableV2 {
pub storage_config: Pubkey,
pub storage_account: Pubkey,
pub stake_account: Pubkey,
pub emissions_wallet: Pubkey,
pub owner: Pubkey,
pub owner_ata: Pubkey,
pub uploader: Pubkey,
pub token_mint: Pubkey,
pub system_program: Pubkey,
pub token_program: Pubkey,
pub associated_token_program: Pubkey,
pub rent: Pubkey,
}Expand description
Generated client accounts for MakeAccountImmutableV2.
Fields
storage_config: PubkeyThis is the StorageConfig accounts that holds all of the admin, uploader keys.
Requires mutability to update global storage counter.
storage_account: PubkeyParent storage account. Requires mutability to update user storage account storage counter.
stake_account: PubkeyThis token account serves as the account which holds user’s stake for file storage.
emissions_wallet: PubkeyThis token account is the SHDW operator emissions wallet
owner: PubkeyFile owner, user, fee-payer Requires mutability since owner/user is fee payer.
owner_ata: PubkeyUser’s token account
uploader: PubkeyUploader needs to sign off on make immutable
token_mint: PubkeyToken mint account
system_program: PubkeySystem Program
token_program: PubkeyToken Program
associated_token_program: PubkeyAssociated Token Program
rent: PubkeyRent