pub struct MigrateStep2 {
pub storage_account: Pubkey,
pub migration: Pubkey,
pub owner: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for MigrateStep2.
Fields
storage_account: PubkeyNew account
migration: PubkeyMigration helper PDA
owner: PubkeyUser that is migrating
system_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for MigrateStep2where
Pubkey: BorshSerialize,
impl BorshSerialize for MigrateStep2where
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for MigrateStep2
impl ToAccountMetas for MigrateStep2
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for MigrateStep2
impl RefUnwindSafe for MigrateStep2
impl Send for MigrateStep2
impl Sync for MigrateStep2
impl Unpin for MigrateStep2
impl UnsafeUnpin for MigrateStep2
impl UnwindSafe for MigrateStep2