Module decrease_storage

Module decrease_storage 

Structs

DecreaseStorageV1
This DecreaseStorage context is used in the instruction which allow users to begin to unstake funds, decreasing their available storage.
DecreaseStorageV2
This DecreaseStorage context is used in the instruction which allow users to begin to unstake funds, decreasing their available storage.
UnstakeInfo

Traits

DecreaseStorage

Functions

handler
This is the function that handles the decrease_storage ix