pub struct DecreaseStorageV2<'info> {Show 13 fields
pub storage_config: Box<Account<'info, StorageConfig>>,
pub storage_account: Account<'info, StorageAccountV2>,
pub unstake_info: Box<Account<'info, UnstakeInfo>>,
pub unstake_account: Box<Account<'info, TokenAccount>>,
pub owner: Signer<'info>,
pub owner_ata: Box<Account<'info, TokenAccount>>,
pub stake_account: Box<Account<'info, TokenAccount>>,
pub token_mint: Account<'info, Mint>,
pub uploader: Signer<'info>,
pub emissions_wallet: Box<Account<'info, TokenAccount>>,
pub system_program: Program<'info, System>,
pub token_program: Program<'info, Token>,
pub rent: Sysvar<'info, Rent>,
}Expand description
This DecreaseStorage context is used in the instruction which allow users to begin
to unstake funds, decreasing their available storage.
Fields
storage_config: Box<Account<'info, StorageConfig>>This is the StorageConfig accounts that holds all of the admin, uploader keys.
storage_account: Account<'info, StorageAccountV2>Parent storage account.
unstake_info: Box<Account<'info, UnstakeInfo>>Account which stores time, epoch last unstaked
unstake_account: Box<Account<'info, TokenAccount>>Account which stores SHDW when unstaking
owner: Signer<'info>File owner, user, fee-payer Requires mutability since owner/user is fee payer.
owner_ata: Box<Account<'info, TokenAccount>>User’s ATA
stake_account: Box<Account<'info, TokenAccount>>This token account serves as the account which holds user’s stake for file storage.
token_mint: Account<'info, Mint>Token mint account
uploader: Signer<'info>Uploader needs to sign off on decrease storage
emissions_wallet: Box<Account<'info, TokenAccount>>Token account holding operator emission funds
system_program: Program<'info, System>System Program
token_program: Program<'info, Token>Token Program
rent: Sysvar<'info, Rent>Rent Program