pub struct InitializeStorageAccountV2<'info> {
pub storage_config: Box<Account<'info, StorageConfig>>,
pub user_info: Box<Account<'info, UserInfo>>,
pub storage_account: Box<Account<'info, StorageAccountV2>>,
pub stake_account: Box<Account<'info, TokenAccount>>,
pub token_mint: Account<'info, Mint>,
pub owner_1: Signer<'info>,
pub uploader: Signer<'info>,
pub owner_1_token_account: Box<Account<'info, TokenAccount>>,
pub system_program: Program<'info, System>,
pub token_program: Program<'info, Token>,
pub rent: Sysvar<'info, Rent>,
}Expand description
This InitializeStorageAccount context is used to initialize a StorageAccount which stores a user’s
storage information including stake token account address, storage requested, and access keys.
Fields
storage_config: Box<Account<'info, StorageConfig>>This account is a PDA that holds the storage configuration, including current cost per byte,
user_info: Box<Account<'info, UserInfo>>This account is a PDA that holds a user’s info (not specific to one storage account).
storage_account: Box<Account<'info, StorageAccountV2>>This account is a PDA that holds a user’s storage account information.
Upgraded to StorageAccountV2.
stake_account: Box<Account<'info, TokenAccount>>This token account serves as the account which holds user’s stake for file storage.
token_mint: Account<'info, Mint>This is the token in question for staking.
owner_1: Signer<'info>This is the user who is initializing the storage account and is automatically added as an admin
uploader: Signer<'info>Uploader needs to sign as this txn needs to be fulfilled on the middleman server to create the ceph bucket
owner_1_token_account: Box<Account<'info, TokenAccount>>This is the user’s token account with which they are staking
system_program: Program<'info, System>System Program
token_program: Program<'info, Token>Token Program
rent: Sysvar<'info, Rent>Rent Program