pub struct UserInfo {
pub account_counter: u32,
pub del_counter: u32,
pub agreed_to_tos: bool,
pub lifetime_bad_csam: bool,
}Fields
account_counter: u32Total number of storage accounts the user has with us
del_counter: u32Total number of storage accounts that have been deleted
agreed_to_tos: boolBoolean denoting that the user agreed to terms of service
lifetime_bad_csam: boolBoolean denoting whether this pubkey has ever had a bad scam scan