pub struct MutableFees<'info> {
pub storage_config: Box<Account<'info, StorageConfig>>,
pub admin: Signer<'info>,
}Expand description
This MutableFees context is used to initialize the account which stores Shadow Drive
configuration data including storage costs, admin pubkeys.
Fields
storage_config: Box<Account<'info, StorageConfig>>This account is a PDA that holds the SPL’s staking and slashing policy. This is the account that signs transactions on behalf of the program to distribute staking rewards.
admin: Signer<'info>This account is the SPL’s staking policy admin. Must be either freeze or mint authority