File

pub struct File {
    pub immutable: bool,
    pub to_be_deleted: bool,
    pub delete_request_epoch: u32,
    pub size: u64,
    pub sha256_hash: [u8; 32],
    pub init_counter_seed: u32,
    pub storage_account: Pubkey,
    pub name: String,
}

Fields

immutable: bool

Mutability

to_be_deleted: bool

Delete flag

delete_request_epoch: u32

Delete request epoch

size: u64

File size (bytes)

sha256_hash: [u8; 32]

File hash (sha256)

init_counter_seed: u32

File counter seed

storage_account: Pubkey

Storage accout

name: String

File name

Implementations

Source

impl File

pub fn store_sha256(&mut self, hash_string: &String)

This function takes in a reference to a string or &str and turns it into a more compact byte array. A sha256 hash only needs 32 bytes to be stored, but takes up 64 bytes when stored with utf-8.