Structs
- Decrease
Storage V1 - This
DecreaseStoragecontext is used in the instruction which allow users to begin to unstake funds, decreasing their available storage. - Decrease
Storage V2 - This
DecreaseStoragecontext is used in the instruction which allow users to begin to unstake funds, decreasing their available storage. - Unstake
Info
Traits
Functions
- handler
- This is the function that handles the
decrease_storageix